import asyncio
import sys
from typing import (
    AsyncIterator,
    Dict,
    Iterable,
    List,
    Optional,
    Tuple,
    Union,
)

import grpc
import orjson as json
from aiogrpcclient import (
    BaseGrpcClient,
    expose,
)
from grpc import StatusCode
from grpc.experimental.aio import AioRpcError
from izihawa_utils.pb_to_json import ParseDict

from .proto import consumer_service_pb2 as consumer_service_pb
from .proto import index_service_pb2 as index_service_pb
from .proto import query_pb2 as query_pb
from .proto import reflection_service_pb2 as reflection_service_pb
from .proto import search_service_pb2 as search_service_pb
from .proto.consumer_service_pb2_grpc import ConsumerApiStub
from .proto.index_service_pb2_grpc import IndexApiStub
from .proto.reflection_service_pb2_grpc import ReflectionApiStub
from .proto.search_service_pb2_grpc import SearchApiStub
from .proto.utils_pb2 import (  # noqa
    Asc,
    Desc,
)


def setup_metadata(session_id, request_id):
    metadata = []
    if session_id:
        metadata.append(('session-id', session_id))
    if request_id:
        metadata.append(('request-id', request_id))
    return metadata


def prepare_search_request(search_request):
    if isinstance(search_request, Dict):
        dict_search_request = search_request
        search_request = search_service_pb.SearchRequest()
        ParseDict(dict_search_request, search_request)
    return search_request


def prepare_query(query):
    if isinstance(query, Dict):
        dict_query = query
        query = query_pb.Query()
        ParseDict(dict_query, query)
    return query


def documents_portion_iter(index_name: str, documents: Iterable, bulk_size: int, conflict_strategy: Optional[str] = None):
    documents_portion = []
    for document in documents:
        documents_portion.append(document)
        if len(documents_portion) > bulk_size:
            yield index_service_pb.IndexDocumentStreamRequest(
                index_name=index_name,
                documents=documents_portion,
                conflict_strategy=conflict_strategy,
            )
            documents_portion = []
    if documents_portion:
        yield index_service_pb.IndexDocumentStreamRequest(
            index_name=index_name,
            documents=documents_portion,
            conflict_strategy=conflict_strategy,
        )

class SummaClient(BaseGrpcClient):
    stub_clses = {
        'consumer_api': ConsumerApiStub,
        'index_api': IndexApiStub,
        'reflection_api': ReflectionApiStub,
        'search_api': SearchApiStub,
    }

    @expose
    async def attach_index(
            self,
            index_name: str,
            index_engine: dict,
            merge_policy: Optional[Dict] = None,
            query_parser_config: Optional[Dict] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.AttachIndexResponse:
        """
        Attach index to Summa. It must be placed under data directory named as `index_name`

        Args:
            index_name: index name
            index_engine: {"file": {}}, {"memory": {}} or {"remote": {"cache_config": {"cache_size": ...}}}
            merge_policy: describes how to select segments for merging, possible values: {"log": {}}, {"temporal": {}}
            query_parser_config: describes how to parse queries by default.
            request_id: request id
            session_id: session id
        """
        query_parser_config_pb = query_pb.QueryParserConfig()
        if query_parser_config:
            ParseDict(query_parser_config, query_parser_config_pb)
        return await self.stubs['index_api'].attach_index(
            index_service_pb.AttachIndexRequest(
                index_name=index_name,
                merge_policy=index_service_pb.MergePolicy(**(merge_policy or {})),
                query_parser_config=query_parser_config_pb,
                **index_engine,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def commit_index(
            self,
            index_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.CommitIndexResponse:
        """
        Commit index asynchronously. A commit will be scheduled and be done eventually.
        Executing commit means stopping all consumption before commit and starting it again
        after.

        Args:
            index_name: index name
            request_id: request id
            session_id: session id
        Returns:
            Commit scheduling result
        """
        return await self.stubs['index_api'].commit_index(
            index_service_pb.CommitIndexRequest(
                index_name=index_name,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def copy_documents(
            self,
            source_index_name: str,
            target_index_name: str,
            conflict_strategy: Optional[str] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.CopyDocumentsResponse:
        """
        Copies all documents from `source` to `target` index

        Args:
            source_index_name: source index name
            target_index_name: target index name
            conflict_strategy: recommended to set to DoNothing for large updates and maintain uniqueness in your application
            request_id: request id
            session_id: session id
        """
        if isinstance(conflict_strategy, str):
            conflict_strategy = index_service_pb.ConflictStrategy.Value(conflict_strategy)
        return await self.stubs['index_api'].copy_documents(
            index_service_pb.CopyDocumentsRequest(
                source_index_name=source_index_name,
                target_index_name=target_index_name,
                conflict_strategy=conflict_strategy,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def create_consumer(
            self,
            index_name: str,
            consumer_name: str,
            bootstrap_servers: List[str],
            group_id: str,
            topics: List[str],
            request_id: str = None,
            session_id: str = None,
    ) -> consumer_service_pb.CreateConsumerResponse:
        """
        Create consumer and corresponding topics in Kafka.
        The newly created consumer starts immediately after creation

        Args:
            index_name: index name
            consumer_name: consumer name that will be used for topic creation in Kafka too
            bootstrap_servers: list of bootstrap servers
            group_id: group_id for Kafka topic consumption
            topics: list of topics
            request_id: request id
            session_id: session id
        """
        return await self.stubs['consumer_api'].create_consumer(
            consumer_service_pb.CreateConsumerRequest(
                consumer_name=consumer_name,
                bootstrap_servers=bootstrap_servers,
                group_id=group_id,
                index_name=index_name,
                topics=topics,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose(with_from_file=True)
    async def create_index(
            self,
            index_name: str,
            schema: Union[str, list],
            index_engine: dict,
            compression: Optional[Union[str, int]] = None,
            blocksize: Optional[int] = None,
            sort_by_field: Optional[Tuple] = None,
            index_attributes: Optional[Dict] = None,
            merge_policy: Optional[Dict] = None,
            query_parser_config: Optional[Dict] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.CreateIndexResponse:
        """
        Create index

        Args:
            index_name: index name
            index_engine: {"file": {}}, {"memory": {}} or {"ipfs": {"cache_config": {"cache_size": ...}}}
            schema: Tantivy index schema
            compression: Tantivy index compression
            blocksize: Docstore blocksize
            index_attributes: Various index attributes such as default fields, multi fields, primary keys etc.
            merge_policy: describes how to select segments for merging, possible values: {"log": {}}, {"temporal": {}}
            query_parser_config: describes how to parse queries by default.
            request_id: request id
            session_id: session id
            sort_by_field: (field_name, order)
        """
        if isinstance(compression, str):
            compression = index_service_pb.Compression.Value(compression)
        elif isinstance(compression, int):
            compression = index_service_pb.Compression.Name(compression)
        if isinstance(schema, list):
            schema = json.dumps(schema)

        query_parser_config_pb = query_pb.QueryParserConfig()
        if query_parser_config:
            ParseDict(query_parser_config, query_parser_config_pb)

        return await self.stubs['index_api'].create_index(
            index_service_pb.CreateIndexRequest(
                index_name=index_name,
                schema=schema,
                compression=compression,
                blocksize=blocksize,
                index_attributes=index_attributes,
                sort_by_field=index_service_pb.SortByField(
                    field=sort_by_field[0],
                    order=sort_by_field[1].capitalize(),
                ) if sort_by_field else None,
                merge_policy=index_service_pb.MergePolicy(**(merge_policy or {})),
                query_parser_config=query_parser_config_pb,
                **index_engine
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose(with_from_file=True)
    async def copy_index(
            self,
            source_index_name: str,
            target_index_name: str,
            target_index_engine: dict,
            merge_policy: Optional[Dict] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.CreateIndexResponse:
        """
        Copies existing index to new engine

        Args:
            source_index_name: source index name
            target_index_name: target index name
            target_index_engine: {"file": {}}, {"memory": {}} or {"ipfs": {"cache_config": {"cache_size": ...}}}
            merge_policy: describes how to select segments for merging, possible values: {"log": {}}, {"temporal": {}}
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].copy_index(
            index_service_pb.CopyIndexRequest(
                source_index_name=source_index_name,
                target_index_name=target_index_name,
                merge_policy=index_service_pb.MergePolicy(**(merge_policy or {})),
                **target_index_engine,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def delete_consumer(
            self,
            consumer_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> consumer_service_pb.DeleteConsumerResponse:
        """
        Delete consumer by index and consumer names

        Args:
            consumer_name: consumer name
            request_id: request id
            session_id: session id
        """
        return await self.stubs['consumer_api'].delete_consumer(
            consumer_service_pb.DeleteConsumerRequest(consumer_name=consumer_name),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def delete_documents(
            self,
            index_name: str,
            query: query_pb.Query,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.IndexDocumentResponse:
        """
        Delete document with primary key

        Args:
            index_name: index name
            query: query used for retrieving documents for deletion
            request_id:
            session_id:
        """
        return await self.stubs['index_api'].delete_documents(
            index_service_pb.DeleteDocumentsRequest(
                index_name=index_name,
                query=query,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def delete_index(
            self,
            index_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.DeleteIndexResponse:
        """
        Delete index

        Args:
            index_name: index name
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].delete_index(
            index_service_pb.DeleteIndexRequest(index_name=index_name),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_consumer(
            self,
            consumer_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> consumer_service_pb.GetConsumerResponse:
        """
        Consumer metadata

        Args:
            consumer_name: consumer name
            request_id: request id
            session_id: session id
        Return:
            Consumer description
        """
        return await self.stubs['consumer_api'].get_consumer(
            consumer_service_pb.GetConsumerRequest(consumer_name=consumer_name),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_consumers(
            self,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> consumer_service_pb.GetConsumersResponse:
        """
        All active consumers

        Args:
            request_id: request id
            session_id: session id
        Returns:
            Consumers list
        """
        return await self.stubs['consumer_api'].get_consumers(
            consumer_service_pb.GetConsumersRequest(),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_index(
            self,
            index_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.GetIndexResponse:
        """
        Index metadata

        Args:
            index_name: index name
            request_id: request id
            session_id: session id
        Returns:
            Index description
        """
        return await self.stubs['index_api'].get_index(
            index_service_pb.GetIndexRequest(index_name=index_name),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_indices(
            self,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.GetIndicesResponse:
        """
        All indices metadata

        Args:
            request_id: request id
            session_id: session id
        Returns:
            Indices list
        """
        return await self.stubs['index_api'].get_indices(
            index_service_pb.GetIndicesRequest(),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_indices_aliases(
            self,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.GetIndicesAliasesResponse:
        """
        Get all aliases for all indices

        Args:
            request_id: request id
            session_id: session id
        Returns:
            Aliases list
        """
        return await self.stubs['index_api'].get_indices_aliases(
            index_service_pb.GetIndicesAliasesRequest(),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def documents(
            self,
            index_name: str,
            query_filter: Optional[dict] = None,
            fields: Optional[List[str]] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> AsyncIterator[str]:
        """
        Retrieve all documents from the index

        Args:
            index_name: index name
            request_id: request id
            session_id: session id
        """
        # asyncfor is buggy: https://github.com/grpc/grpc/issues/32005
        streaming_call = self.stubs['index_api'].documents(
            index_service_pb.DocumentsRequest(
                index_name=index_name,
                query_filter=prepare_query(query_filter),
                fields=fields,
            ),
            metadata=setup_metadata(session_id, request_id),
        )
        while True:
            document = await asyncio.create_task(streaming_call.read())
            if document == grpc.aio.EOF:
                break
            yield document.document

    @expose
    async def index_document_stream(
            self,
            index_name: str,
            documents: Union[Iterable[str], str] = None,
            conflict_strategy: Optional[str] = None,
            bulk_size: int = 100,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.IndexDocumentStreamResponse:
        """
        Index documents bulky

        Args:
            index_name: index name
            documents: list of bytes
            conflict_strategy: recommended to set to DoNothing for large updates and maintain uniqueness in your application
            bulk_size: document portion size to send
            request_id: request id
            session_id: session id
        """
        if isinstance(conflict_strategy, str):
            conflict_strategy = index_service_pb.ConflictStrategy.Value(conflict_strategy)

        if documents is None and not sys.stdin.isatty():
            def documents_iter():
                for line in sys.stdin:
                    yield line.strip().encode()

            documents = documents_iter()

        return await self.stubs['index_api'].index_document_stream(
            documents_portion_iter(index_name, documents, bulk_size, conflict_strategy=conflict_strategy),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def index_document(
            self,
            index_name: str,
            document: Union[dict, bytes, str],
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.IndexDocumentResponse:
        """
        Index document

        Args:
            index_name: index name
            document: bytes
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].index_document(
            index_service_pb.IndexDocumentRequest(
                index_name=index_name,
                document=json.dumps(document) if isinstance(document, dict) else document,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def search(
            self,
            search_request: dict,
            ignore_not_found: bool = False,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> query_pb.SearchResponse:
        """Send search request. `Query` object can be created manually or by using `aiosumma.parser` module.

        Args:
            search_request:
            ignore_not_found: do not raise `StatusCode.NOT_FOUND` and return empty SearchResponse
            request_id: request id
            session_id: session id
        """
        try:
            return await self.stubs['search_api'].search(
                prepare_search_request(search_request),
                metadata=setup_metadata(session_id, request_id),
            )
        except AioRpcError as e:
            if ignore_not_found and e.code() == StatusCode.NOT_FOUND:
                return query_pb.SearchResponse()
            raise

    @expose
    async def search_documents(
            self,
            search_request: dict,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> List[dict]:
        """Send search request and interprets first collector as, thus parse returned documents as json.

        Args:
            search_request: index queries
            request_id: request id
            session_id: session id
        """
        search_results = await self.search(search_request=search_request, request_id=request_id, session_id=session_id)
        return [
            json.loads(scored_document.document)
            for scored_document in search_results.collector_outputs[0].documents.scored_documents
        ]

    @expose
    async def merge_segments(
            self,
            index_name: str,
            segment_ids: List[str],
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.MergeSegmentsResponse:
        """
        Merge a list of segments into a single one

        Args:
            index_name: index name
            segment_ids: segment ids
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].merge_segments(
            index_service_pb.MergeSegmentsRequest(index_name=index_name, segment_ids=segment_ids),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def set_index_alias(
            self,
            index_alias: str,
            index_name: str,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.SetIndexAliasResponse:
        """
        Set or reassign the alias for an index

        Args:
            index_alias: index alias
            index_name: index name
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].set_index_alias(
            index_service_pb.SetIndexAliasRequest(index_alias=index_alias, index_name=index_name),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def vacuum_index(
            self,
            index_name: str,
            excluded_segments: Optional[List[str]] = None,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.VacuumIndexResponse:
        """
        Vacuuming index. It cleans every segment from deleted documents, one by one.

        Args:
            index_name: index name
            excluded_segments: segments that must not be merged
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].vacuum_index(
            index_service_pb.VacuumIndexRequest(index_name=index_name, excluded_segments=excluded_segments),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def warmup_index(
            self,
            index_name: str,
            is_full: bool = False,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.VacuumIndexResponse:
        """
        Warm index up. It loads all hot parts or index into memory and makes further first queries to the index faster.

        Args:
            index_name: index name
            is_full: should full or partial warm up be done
            request_id: request id
            session_id: session id
        """
        return await self.stubs['index_api'].warmup_index(
            index_service_pb.WarmupIndexRequest(index_name=index_name, is_full=is_full),
            metadata=setup_metadata(session_id, request_id),
        )

    @expose
    async def get_top_terms(
            self,
            index_name: str,
            field_name: str,
            top_k: int,
            request_id: Optional[str] = None,
            session_id: Optional[str] = None,
    ) -> index_service_pb.VacuumIndexResponse:
        """
        Get top terms by the number for the index

        Args:
            index_name: index name
            field_name: field name
            top_k: extract top-K terms
            request_id: request id
            session_id: session id
        """
        return await self.stubs['reflection_api'].get_top_terms(
            reflection_service_pb.GetTopTermsRequest(
                index_name=index_name,
                field_name=field_name,
                top_k=top_k,
            ),
            metadata=setup_metadata(session_id, request_id),
        )

    async def get_one_by_field_value(self, index_alias, field, value):
        response = await self.search({
            'index_alias': index_alias,
            'query': {'term': {'field': field, 'value': value}},
            'collectors': [{'top_docs': {'limit': 1}}],
        })
        if response.collector_outputs[0].documents.scored_documents:
            return json.loads(response.collector_outputs[0].documents.scored_documents[0].document)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import query_pb2 as query__pb2
from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13index_service.proto\x12\x0bsumma.proto\x1a\x0bquery.proto\x1a\x0butils.proto\"3\n\nPrimaryKey\x12\r\n\x03str\x18\x01 \x01(\tH\x00\x12\r\n\x03i64\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"\x7f\n\x0bMergePolicy\x12*\n\x03log\x18\x0b \x01(\x0b\x32\x1b.summa.proto.LogMergePolicyH\x00\x12\x34\n\x08temporal\x18\x0c \x01(\x0b\x32 .summa.proto.TemporalMergePolicyH\x00\x42\x0e\n\x0cmerge_policy\"\x19\n\x17\x41ttachFileEngineRequest\"L\n\x19\x41ttachRemoteEngineRequest\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.summa.proto.RemoteEngineConfig\"\x95\x02\n\x12\x41ttachIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x34\n\x04\x66ile\x18\x02 \x01(\x0b\x32$.summa.proto.AttachFileEngineRequestH\x00\x12\x38\n\x06remote\x18\x03 \x01(\x0b\x32&.summa.proto.AttachRemoteEngineRequestH\x00\x12.\n\x0cmerge_policy\x18\n \x01(\x0b\x32\x18.summa.proto.MergePolicy\x12;\n\x13query_parser_config\x18\x0b \x01(\x0b\x32\x1e.summa.proto.QueryParserConfigB\x0e\n\x0cindex_engine\"C\n\x13\x41ttachIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"(\n\x12\x43ommitIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"+\n\x13\x43ommitIndexResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\"\xa1\x01\n\x14\x43opyDocumentsRequest\x12\x19\n\x11source_index_name\x18\x01 \x01(\t\x12\x19\n\x11target_index_name\x18\x02 \x01(\t\x12=\n\x11\x63onflict_strategy\x18\x03 \x01(\x0e\x32\x1d.summa.proto.ConflictStrategyH\x00\x88\x01\x01\x42\x14\n\x12_conflict_strategy\"G\n\x15\x43opyDocumentsResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\x12\x18\n\x10\x63opied_documents\x18\x02 \x01(\r\"\xff\x01\n\x10\x43opyIndexRequest\x12\x19\n\x11source_index_name\x18\x01 \x01(\t\x12\x19\n\x11target_index_name\x18\x02 \x01(\t\x12\x34\n\x04\x66ile\x18\x03 \x01(\x0b\x32$.summa.proto.CreateFileEngineRequestH\x00\x12\x38\n\x06memory\x18\x04 \x01(\x0b\x32&.summa.proto.CreateMemoryEngineRequestH\x00\x12.\n\x0cmerge_policy\x18\x06 \x01(\x0b\x32\x18.summa.proto.MergePolicyB\x15\n\x13target_index_engine\"A\n\x11\x43opyIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"?\n\x0bSortByField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12!\n\x05order\x18\x02 \x01(\x0e\x32\x12.summa.proto.Order\"\x19\n\x17\x43reateFileEngineRequest\"\x1b\n\x19\x43reateMemoryEngineRequest\"9\n\x0bMappedField\x12\x14\n\x0csource_field\x18\x01 \x01(\t\x12\x14\n\x0ctarget_field\x18\x02 \x01(\t\"\xe7\x01\n\x0fIndexAttributes\x12\x12\n\ncreated_at\x18\x01 \x01(\x04\x12\x15\n\runique_fields\x18\x02 \x03(\t\x12\x14\n\x0cmulti_fields\x18\x04 \x03(\t\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x11\x63onflict_strategy\x18\x08 \x01(\x0e\x32\x1d.summa.proto.ConflictStrategy\x12/\n\rmapped_fields\x18\t \x03(\x0b\x32\x18.summa.proto.MappedFieldB\x0e\n\x0c_description\"\xfa\x03\n\x12\x43reateIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x34\n\x04\x66ile\x18\x07 \x01(\x0b\x32$.summa.proto.CreateFileEngineRequestH\x00\x12\x38\n\x06memory\x18\x08 \x01(\x0b\x32&.summa.proto.CreateMemoryEngineRequestH\x00\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12-\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32\x18.summa.proto.Compression\x12\x16\n\tblocksize\x18\x04 \x01(\rH\x01\x88\x01\x01\x12\x34\n\rsort_by_field\x18\x05 \x01(\x0b\x32\x18.summa.proto.SortByFieldH\x02\x88\x01\x01\x12\x36\n\x10index_attributes\x18\x06 \x01(\x0b\x32\x1c.summa.proto.IndexAttributes\x12.\n\x0cmerge_policy\x18\x14 \x01(\x0b\x32\x18.summa.proto.MergePolicy\x12;\n\x13query_parser_config\x18\x15 \x01(\x0b\x32\x1e.summa.proto.QueryParserConfigB\x0e\n\x0cindex_engineB\x0c\n\n_blocksizeB\x10\n\x0e_sort_by_field\"C\n\x13\x43reateIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"O\n\x16\x44\x65leteDocumentsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\"4\n\x17\x44\x65leteDocumentsResponse\x12\x19\n\x11\x64\x65leted_documents\x18\x01 \x01(\x04\"(\n\x12\x44\x65leteIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"1\n\x13\x44\x65leteIndexResponse\x12\x1a\n\x12\x64\x65leted_index_name\x18\x01 \x01(\t\"\x1a\n\x18GetIndicesAliasesRequest\"\xa7\x01\n\x19GetIndicesAliasesResponse\x12S\n\x0findices_aliases\x18\x01 \x03(\x0b\x32:.summa.proto.GetIndicesAliasesResponse.IndicesAliasesEntry\x1a\x35\n\x13IndicesAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fGetIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"@\n\x10GetIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"\x13\n\x11GetIndicesRequest\")\n\x12GetIndicesResponse\x12\x13\n\x0bindex_names\x18\x01 \x03(\t\"\x98\x01\n\x1aIndexDocumentStreamRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x11\n\tdocuments\x18\x02 \x03(\x0c\x12=\n\x11\x63onflict_strategy\x18\x03 \x01(\x0e\x32\x1d.summa.proto.ConflictStrategyH\x00\x88\x01\x01\x42\x14\n\x12_conflict_strategy\"^\n\x1bIndexDocumentStreamResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\x12\x14\n\x0csuccess_docs\x18\x02 \x01(\x04\x12\x13\n\x0b\x66\x61iled_docs\x18\x03 \x01(\x04\"<\n\x14IndexDocumentRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocument\x18\x02 \x01(\x0c\"\x17\n\x15IndexDocumentResponse\"?\n\x14MergeSegmentsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x13\n\x0bsegment_ids\x18\x02 \x03(\t\"?\n\x15MergeSegmentsResponse\x12\x17\n\nsegment_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_segment_id\"?\n\x14SetIndexAliasRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t\"G\n\x15SetIndexAliasResponse\x12\x1b\n\x0eold_index_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x11\n\x0f_old_index_name\"v\n\x10\x44ocumentsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\x12-\n\x0cquery_filter\x18\x03 \x01(\x0b\x32\x12.summa.proto.QueryH\x00\x88\x01\x01\x42\x0f\n\r_query_filter\"%\n\x11\x44ocumentsResponse\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\"C\n\x12VacuumIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x19\n\x11\x65xcluded_segments\x18\x02 \x03(\t\"0\n\x13VacuumIndexResponse\x12\x19\n\x11\x66reed_space_bytes\x18\x01 \x01(\x04\"9\n\x12WarmupIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0f\n\x07is_full\x18\x02 \x01(\x08\"+\n\x13WarmupIndexResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\" \n\x10\x46ileEngineConfig\x12\x0c\n\x04path\x18\x01 \x01(\t\"$\n\x12MemoryEngineConfig\x12\x0e\n\x06schema\x18\x01 \x01(\t\"!\n\x0b\x43\x61\x63heConfig\x12\x12\n\ncache_size\x18\x01 \x01(\x04\"\x9a\x02\n\x12RemoteEngineConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x14\n\x0curl_template\x18\x02 \x01(\t\x12N\n\x10headers_template\x18\x03 \x03(\x0b\x32\x34.summa.proto.RemoteEngineConfig.HeadersTemplateEntry\x12.\n\x0c\x63\x61\x63he_config\x18\x04 \x01(\x0b\x32\x18.summa.proto.CacheConfig\x12\x17\n\ntimeout_ms\x18\x05 \x01(\rH\x00\x88\x01\x01\x1a\x36\n\x14HeadersTemplateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_timeout_ms\"#\n\x0eLogMergePolicy\x12\x11\n\tis_frozen\x18\x01 \x01(\x08\"4\n\x13TemporalMergePolicy\x12\x1d\n\x15merge_older_then_secs\x18\x01 \x01(\x04\"\x9f\x02\n\x11IndexEngineConfig\x12-\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1d.summa.proto.FileEngineConfigH\x00\x12\x31\n\x06memory\x18\x02 \x01(\x0b\x32\x1f.summa.proto.MemoryEngineConfigH\x00\x12\x31\n\x06remote\x18\x03 \x01(\x0b\x32\x1f.summa.proto.RemoteEngineConfigH\x00\x12.\n\x0cmerge_policy\x18\n \x01(\x0b\x32\x18.summa.proto.MergePolicy\x12;\n\x13query_parser_config\x18\x0b \x01(\x0b\x32\x1e.summa.proto.QueryParserConfigB\x08\n\x06\x63onfig\"\xec\x01\n\x10IndexDescription\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x15\n\rindex_aliases\x18\x02 \x03(\t\x12\x34\n\x0cindex_engine\x18\x03 \x01(\x0b\x32\x1e.summa.proto.IndexEngineConfig\x12\x10\n\x08num_docs\x18\x04 \x01(\x04\x12-\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32\x18.summa.proto.Compression\x12\x36\n\x10index_attributes\x18\x06 \x01(\x0b\x32\x1c.summa.proto.IndexAttributes\"*\n\x16IndexDocumentOperation\x12\x10\n\x08\x64ocument\x18\x01 \x01(\x0c\"\\\n\x0eIndexOperation\x12=\n\x0eindex_document\x18\x02 \x01(\x0b\x32#.summa.proto.IndexDocumentOperationH\x00\x42\x0b\n\toperation*R\n\x10\x43onflictStrategy\x12\x0e\n\nDO_NOTHING\x10\x00\x12\x14\n\x10OVERWRITE_ALWAYS\x10\x01\x12\r\n\tOVERWRITE\x10\x02\x12\t\n\x05MERGE\x10\x03*|\n\x0b\x43ompression\x12\x08\n\x04None\x10\x00\x12\n\n\x06\x42rotli\x10\x01\x12\x07\n\x03Lz4\x10\x02\x12\n\n\x06Snappy\x10\x03\x12\x08\n\x04Zstd\x10\x04\x12\t\n\x05Zstd7\x10\x05\x12\t\n\x05Zstd9\x10\x06\x12\n\n\x06Zstd14\x10\x07\x12\n\n\x06Zstd19\x10\x08\x12\n\n\x06Zstd22\x10\t2\xeb\x0b\n\x08IndexApi\x12S\n\x0c\x61ttach_index\x12\x1f.summa.proto.AttachIndexRequest\x1a .summa.proto.AttachIndexResponse\"\x00\x12S\n\x0c\x63ommit_index\x12\x1f.summa.proto.CommitIndexRequest\x1a .summa.proto.CommitIndexResponse\"\x00\x12Y\n\x0e\x63opy_documents\x12!.summa.proto.CopyDocumentsRequest\x1a\".summa.proto.CopyDocumentsResponse\"\x00\x12S\n\x0c\x63reate_index\x12\x1f.summa.proto.CreateIndexRequest\x1a .summa.proto.CreateIndexResponse\"\x00\x12M\n\ncopy_index\x12\x1d.summa.proto.CopyIndexRequest\x1a\x1e.summa.proto.CopyIndexResponse\"\x00\x12_\n\x10\x64\x65lete_documents\x12#.summa.proto.DeleteDocumentsRequest\x1a$.summa.proto.DeleteDocumentsResponse\"\x00\x12S\n\x0c\x64\x65lete_index\x12\x1f.summa.proto.DeleteIndexRequest\x1a .summa.proto.DeleteIndexResponse\"\x00\x12N\n\tdocuments\x12\x1d.summa.proto.DocumentsRequest\x1a\x1e.summa.proto.DocumentsResponse\"\x00\x30\x01\x12\x66\n\x13get_indices_aliases\x12%.summa.proto.GetIndicesAliasesRequest\x1a&.summa.proto.GetIndicesAliasesResponse\"\x00\x12J\n\tget_index\x12\x1c.summa.proto.GetIndexRequest\x1a\x1d.summa.proto.GetIndexResponse\"\x00\x12P\n\x0bget_indices\x12\x1e.summa.proto.GetIndicesRequest\x1a\x1f.summa.proto.GetIndicesResponse\"\x00\x12n\n\x15index_document_stream\x12\'.summa.proto.IndexDocumentStreamRequest\x1a(.summa.proto.IndexDocumentStreamResponse\"\x00(\x01\x12Y\n\x0eindex_document\x12!.summa.proto.IndexDocumentRequest\x1a\".summa.proto.IndexDocumentResponse\"\x00\x12Y\n\x0emerge_segments\x12!.summa.proto.MergeSegmentsRequest\x1a\".summa.proto.MergeSegmentsResponse\"\x00\x12Z\n\x0fset_index_alias\x12!.summa.proto.SetIndexAliasRequest\x1a\".summa.proto.SetIndexAliasResponse\"\x00\x12S\n\x0cvacuum_index\x12\x1f.summa.proto.VacuumIndexRequest\x1a .summa.proto.VacuumIndexResponse\"\x00\x12S\n\x0cwarmup_index\x12\x1f.summa.proto.WarmupIndexRequest\x1a .summa.proto.WarmupIndexResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'index_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._options = None
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._serialized_options = b'8\001'
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._options = None
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._serialized_options = b'8\001'
  _globals['_CONFLICTSTRATEGY']._serialized_start=5072
  _globals['_CONFLICTSTRATEGY']._serialized_end=5154
  _globals['_COMPRESSION']._serialized_start=5156
  _globals['_COMPRESSION']._serialized_end=5280
  _globals['_PRIMARYKEY']._serialized_start=62
  _globals['_PRIMARYKEY']._serialized_end=113
  _globals['_MERGEPOLICY']._serialized_start=115
  _globals['_MERGEPOLICY']._serialized_end=242
  _globals['_ATTACHFILEENGINEREQUEST']._serialized_start=244
  _globals['_ATTACHFILEENGINEREQUEST']._serialized_end=269
  _globals['_ATTACHREMOTEENGINEREQUEST']._serialized_start=271
  _globals['_ATTACHREMOTEENGINEREQUEST']._serialized_end=347
  _globals['_ATTACHINDEXREQUEST']._serialized_start=350
  _globals['_ATTACHINDEXREQUEST']._serialized_end=627
  _globals['_ATTACHINDEXRESPONSE']._serialized_start=629
  _globals['_ATTACHINDEXRESPONSE']._serialized_end=696
  _globals['_COMMITINDEXREQUEST']._serialized_start=698
  _globals['_COMMITINDEXREQUEST']._serialized_end=738
  _globals['_COMMITINDEXRESPONSE']._serialized_start=740
  _globals['_COMMITINDEXRESPONSE']._serialized_end=783
  _globals['_COPYDOCUMENTSREQUEST']._serialized_start=786
  _globals['_COPYDOCUMENTSREQUEST']._serialized_end=947
  _globals['_COPYDOCUMENTSRESPONSE']._serialized_start=949
  _globals['_COPYDOCUMENTSRESPONSE']._serialized_end=1020
  _globals['_COPYINDEXREQUEST']._serialized_start=1023
  _globals['_COPYINDEXREQUEST']._serialized_end=1278
  _globals['_COPYINDEXRESPONSE']._serialized_start=1280
  _globals['_COPYINDEXRESPONSE']._serialized_end=1345
  _globals['_SORTBYFIELD']._serialized_start=1347
  _globals['_SORTBYFIELD']._serialized_end=1410
  _globals['_CREATEFILEENGINEREQUEST']._serialized_start=1412
  _globals['_CREATEFILEENGINEREQUEST']._serialized_end=1437
  _globals['_CREATEMEMORYENGINEREQUEST']._serialized_start=1439
  _globals['_CREATEMEMORYENGINEREQUEST']._serialized_end=1466
  _globals['_MAPPEDFIELD']._serialized_start=1468
  _globals['_MAPPEDFIELD']._serialized_end=1525
  _globals['_INDEXATTRIBUTES']._serialized_start=1528
  _globals['_INDEXATTRIBUTES']._serialized_end=1759
  _globals['_CREATEINDEXREQUEST']._serialized_start=1762
  _globals['_CREATEINDEXREQUEST']._serialized_end=2268
  _globals['_CREATEINDEXRESPONSE']._serialized_start=2270
  _globals['_CREATEINDEXRESPONSE']._serialized_end=2337
  _globals['_DELETEDOCUMENTSREQUEST']._serialized_start=2339
  _globals['_DELETEDOCUMENTSREQUEST']._serialized_end=2418
  _globals['_DELETEDOCUMENTSRESPONSE']._serialized_start=2420
  _globals['_DELETEDOCUMENTSRESPONSE']._serialized_end=2472
  _globals['_DELETEINDEXREQUEST']._serialized_start=2474
  _globals['_DELETEINDEXREQUEST']._serialized_end=2514
  _globals['_DELETEINDEXRESPONSE']._serialized_start=2516
  _globals['_DELETEINDEXRESPONSE']._serialized_end=2565
  _globals['_GETINDICESALIASESREQUEST']._serialized_start=2567
  _globals['_GETINDICESALIASESREQUEST']._serialized_end=2593
  _globals['_GETINDICESALIASESRESPONSE']._serialized_start=2596
  _globals['_GETINDICESALIASESRESPONSE']._serialized_end=2763
  _globals['_GETINDICESALIASESRESPONSE_INDICESALIASESENTRY']._serialized_start=2710
  _globals['_GETINDICESALIASESRESPONSE_INDICESALIASESENTRY']._serialized_end=2763
  _globals['_GETINDEXREQUEST']._serialized_start=2765
  _globals['_GETINDEXREQUEST']._serialized_end=2802
  _globals['_GETINDEXRESPONSE']._serialized_start=2804
  _globals['_GETINDEXRESPONSE']._serialized_end=2868
  _globals['_GETINDICESREQUEST']._serialized_start=2870
  _globals['_GETINDICESREQUEST']._serialized_end=2889
  _globals['_GETINDICESRESPONSE']._serialized_start=2891
  _globals['_GETINDICESRESPONSE']._serialized_end=2932
  _globals['_INDEXDOCUMENTSTREAMREQUEST']._serialized_start=2935
  _globals['_INDEXDOCUMENTSTREAMREQUEST']._serialized_end=3087
  _globals['_INDEXDOCUMENTSTREAMRESPONSE']._serialized_start=3089
  _globals['_INDEXDOCUMENTSTREAMRESPONSE']._serialized_end=3183
  _globals['_INDEXDOCUMENTREQUEST']._serialized_start=3185
  _globals['_INDEXDOCUMENTREQUEST']._serialized_end=3245
  _globals['_INDEXDOCUMENTRESPONSE']._serialized_start=3247
  _globals['_INDEXDOCUMENTRESPONSE']._serialized_end=3270
  _globals['_MERGESEGMENTSREQUEST']._serialized_start=3272
  _globals['_MERGESEGMENTSREQUEST']._serialized_end=3335
  _globals['_MERGESEGMENTSRESPONSE']._serialized_start=3337
  _globals['_MERGESEGMENTSRESPONSE']._serialized_end=3400
  _globals['_SETINDEXALIASREQUEST']._serialized_start=3402
  _globals['_SETINDEXALIASREQUEST']._serialized_end=3465
  _globals['_SETINDEXALIASRESPONSE']._serialized_start=3467
  _globals['_SETINDEXALIASRESPONSE']._serialized_end=3538
  _globals['_DOCUMENTSREQUEST']._serialized_start=3540
  _globals['_DOCUMENTSREQUEST']._serialized_end=3658
  _globals['_DOCUMENTSRESPONSE']._serialized_start=3660
  _globals['_DOCUMENTSRESPONSE']._serialized_end=3697
  _globals['_VACUUMINDEXREQUEST']._serialized_start=3699
  _globals['_VACUUMINDEXREQUEST']._serialized_end=3766
  _globals['_VACUUMINDEXRESPONSE']._serialized_start=3768
  _globals['_VACUUMINDEXRESPONSE']._serialized_end=3816
  _globals['_WARMUPINDEXREQUEST']._serialized_start=3818
  _globals['_WARMUPINDEXREQUEST']._serialized_end=3875
  _globals['_WARMUPINDEXRESPONSE']._serialized_start=3877
  _globals['_WARMUPINDEXRESPONSE']._serialized_end=3920
  _globals['_FILEENGINECONFIG']._serialized_start=3922
  _globals['_FILEENGINECONFIG']._serialized_end=3954
  _globals['_MEMORYENGINECONFIG']._serialized_start=3956
  _globals['_MEMORYENGINECONFIG']._serialized_end=3992
  _globals['_CACHECONFIG']._serialized_start=3994
  _globals['_CACHECONFIG']._serialized_end=4027
  _globals['_REMOTEENGINECONFIG']._serialized_start=4030
  _globals['_REMOTEENGINECONFIG']._serialized_end=4312
  _globals['_REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY']._serialized_start=4243
  _globals['_REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY']._serialized_end=4297
  _globals['_LOGMERGEPOLICY']._serialized_start=4314
  _globals['_LOGMERGEPOLICY']._serialized_end=4349
  _globals['_TEMPORALMERGEPOLICY']._serialized_start=4351
  _globals['_TEMPORALMERGEPOLICY']._serialized_end=4403
  _globals['_INDEXENGINECONFIG']._serialized_start=4406
  _globals['_INDEXENGINECONFIG']._serialized_end=4693
  _globals['_INDEXDESCRIPTION']._serialized_start=4696
  _globals['_INDEXDESCRIPTION']._serialized_end=4932
  _globals['_INDEXDOCUMENTOPERATION']._serialized_start=4934
  _globals['_INDEXDOCUMENTOPERATION']._serialized_end=4976
  _globals['_INDEXOPERATION']._serialized_start=4978
  _globals['_INDEXOPERATION']._serialized_end=5070
  _globals['_INDEXAPI']._serialized_start=5283
  _globals['_INDEXAPI']._serialized_end=6798
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import reflection_service_pb2 as reflection__service__pb2


class ReflectionApiStub(object):
    """Analyzes indices
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_top_terms = channel.unary_unary(
                '/summa.proto.ReflectionApi/get_top_terms',
                request_serializer=reflection__service__pb2.GetTopTermsRequest.SerializeToString,
                response_deserializer=reflection__service__pb2.GetTopTermsResponse.FromString,
                )


class ReflectionApiServicer(object):
    """Analyzes indices
    """

    def get_top_terms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReflectionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_top_terms': grpc.unary_unary_rpc_method_handler(
                    servicer.get_top_terms,
                    request_deserializer=reflection__service__pb2.GetTopTermsRequest.FromString,
                    response_serializer=reflection__service__pb2.GetTopTermsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'summa.proto.ReflectionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReflectionApi(object):
    """Analyzes indices
    """

    @staticmethod
    def get_top_terms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.ReflectionApi/get_top_terms',
            reflection__service__pb2.GetTopTermsRequest.SerializeToString,
            reflection__service__pb2.GetTopTermsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bquery.proto\x12\x0bsumma.proto\x1a\x0butils.proto\"\'\n\x15TermFieldMapperConfig\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\"\x1d\n\x1bMatchQueryBooleanShouldMode\"2\n\x1bMatchQueryDisjuctionMaxMode\x12\x13\n\x0btie_breaker\x18\x01 \x01(\x02\"R\n\x14\x45xactMatchesPromoter\x12\x0c\n\x04slop\x18\x01 \x01(\r\x12\x12\n\x05\x62oost\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x0e\n\x06\x66ields\x18\x03 \x03(\tB\x08\n\x06_boost\"B\n\x12NerMatchesPromoter\x12\x12\n\x05\x62oost\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x0e\n\x06\x66ields\x18\x02 \x03(\tB\x08\n\x06_boost\"X\n\x10MorphologyConfig\x12&\n\x19\x64\x65rive_tenses_coefficient\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x1c\n\x1a_derive_tenses_coefficient\"\xd3\x07\n\x11QueryParserConfig\x12G\n\rfield_aliases\x18\x01 \x03(\x0b\x32\x30.summa.proto.QueryParserConfig.FieldAliasesEntry\x12\x45\n\x0c\x66ield_boosts\x18\x02 \x03(\x0b\x32/.summa.proto.QueryParserConfig.FieldBoostsEntry\x12]\n\x19term_field_mapper_configs\x18\x03 \x03(\x0b\x32:.summa.proto.QueryParserConfig.TermFieldMapperConfigsEntry\x12\x12\n\nterm_limit\x18\x04 \x01(\r\x12\x16\n\x0e\x64\x65\x66\x61ult_fields\x18\x05 \x03(\t\x12G\n\x13\x62oolean_should_mode\x18\x06 \x01(\x0b\x32(.summa.proto.MatchQueryBooleanShouldModeH\x00\x12G\n\x13\x64isjuction_max_mode\x18\x07 \x01(\x0b\x32(.summa.proto.MatchQueryDisjuctionMaxModeH\x00\x12\x41\n\x16\x65xact_matches_promoter\x18\x08 \x01(\x0b\x32!.summa.proto.ExactMatchesPromoter\x12\x16\n\x0eremoved_fields\x18\t \x03(\t\x12Q\n\x12morphology_configs\x18\n \x03(\x0b\x32\x35.summa.proto.QueryParserConfig.MorphologyConfigsEntry\x12\x1b\n\x0equery_language\x18\x0b \x01(\tH\x01\x88\x01\x01\x1a\x33\n\x11\x46ieldAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x46ieldBoostsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x61\n\x1bTermFieldMapperConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".summa.proto.TermFieldMapperConfig:\x02\x38\x01\x1aW\n\x16MorphologyConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.summa.proto.MorphologyConfig:\x02\x38\x01\x42\x0e\n\x0c\x64\x65\x66\x61ult_modeB\x11\n\x0f_query_language\"_\n\x0eSearchResponse\x12\x14\n\x0c\x65lapsed_secs\x18\x01 \x01(\x01\x12\x37\n\x11\x63ollector_outputs\x18\x02 \x03(\x0b\x32\x1c.summa.proto.CollectorOutput\"\xad\x04\n\x05Query\x12,\n\x07\x62oolean\x18\x01 \x01(\x0b\x32\x19.summa.proto.BooleanQueryH\x00\x12(\n\x05match\x18\x02 \x01(\x0b\x32\x17.summa.proto.MatchQueryH\x00\x12(\n\x05regex\x18\x03 \x01(\x0b\x32\x17.summa.proto.RegexQueryH\x00\x12&\n\x04term\x18\x04 \x01(\x0b\x32\x16.summa.proto.TermQueryH\x00\x12*\n\x06phrase\x18\x05 \x01(\x0b\x32\x18.summa.proto.PhraseQueryH\x00\x12(\n\x05range\x18\x06 \x01(\x0b\x32\x17.summa.proto.RangeQueryH\x00\x12$\n\x03\x61ll\x18\x07 \x01(\x0b\x32\x15.summa.proto.AllQueryH\x00\x12\x38\n\x0emore_like_this\x18\x08 \x01(\x0b\x32\x1e.summa.proto.MoreLikeThisQueryH\x00\x12(\n\x05\x62oost\x18\t \x01(\x0b\x32\x17.summa.proto.BoostQueryH\x00\x12;\n\x0f\x64isjunction_max\x18\n \x01(\x0b\x32 .summa.proto.DisjunctionMaxQueryH\x00\x12(\n\x05\x65mpty\x18\x0b \x01(\x0b\x32\x17.summa.proto.EmptyQueryH\x00\x12*\n\x06\x65xists\x18\x0c \x01(\x0b\x32\x18.summa.proto.ExistsQueryH\x00\x42\x07\n\x05query\"\n\n\x08\x41llQuery\"\x0c\n\nEmptyQuery\">\n\nBoostQuery\x12!\n\x05query\x18\x01 \x01(\x0b\x32\x12.summa.proto.Query\x12\r\n\x05score\x18\x02 \x01(\t\"Q\n\x13\x44isjunctionMaxQuery\x12%\n\tdisjuncts\x18\x01 \x03(\x0b\x32\x12.summa.proto.Query\x12\x13\n\x0btie_breaker\x18\x02 \x01(\t\"\x91\x03\n\x11MoreLikeThisQuery\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12\x1e\n\x11min_doc_frequency\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1e\n\x11max_doc_frequency\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1f\n\x12min_term_frequency\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0fmax_query_terms\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0fmin_word_length\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fmax_word_length\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12\x12\n\x05\x62oost\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x12\n\nstop_words\x18\t \x03(\tB\x14\n\x12_min_doc_frequencyB\x14\n\x12_max_doc_frequencyB\x15\n\x13_min_term_frequencyB\x12\n\x10_max_query_termsB\x12\n\x10_min_word_lengthB\x12\n\x10_max_word_lengthB\x08\n\x06_boost\"9\n\x0bPhraseQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04slop\x18\x03 \x01(\r\">\n\nRangeQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.summa.proto.Range\"u\n\nMatchQuery\x12\r\n\x05value\x18\x01 \x01(\t\x12@\n\x13query_parser_config\x18\x02 \x01(\x0b\x32\x1e.summa.proto.QueryParserConfigH\x00\x88\x01\x01\x42\x16\n\x14_query_parser_config\"W\n\x0f\x42ooleanSubquery\x12!\n\x05occur\x18\x01 \x01(\x0e\x32\x12.summa.proto.Occur\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\"@\n\x0c\x42ooleanQuery\x12\x30\n\nsubqueries\x18\x01 \x03(\x0b\x32\x1c.summa.proto.BooleanSubquery\"*\n\nRegexQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\tTermQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1c\n\x0b\x45xistsQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\xa3\x01\n\x0b\x43ustomOrder\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12#\n\x05\x63ount\x18\x02 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12\x19\n\x0fsub_aggregation\x18\x03 \x01(\tH\x00\x12!\n\x05order\x18\x04 \x01(\x0e\x32\x12.summa.proto.OrderB\x0e\n\x0corder_target\"*\n\x03Key\x12\r\n\x03str\x18\x01 \x01(\tH\x00\x12\r\n\x03\x66\x36\x34\x18\x02 \x01(\x01H\x00\x42\x05\n\x03key\"U\n\x05Range\x12\x0c\n\x04left\x18\x01 \x01(\t\x12\r\n\x05right\x18\x02 \x01(\t\x12\x16\n\x0eincluding_left\x18\x03 \x01(\x08\x12\x17\n\x0fincluding_right\x18\x04 \x01(\x08\":\n\x05Score\x12\x13\n\tf64_score\x18\x01 \x01(\x01H\x00\x12\x13\n\tu64_score\x18\x02 \x01(\x04H\x00\x42\x07\n\x05score\"%\n\tHighlight\x12\x0c\n\x04\x66rom\x18\x01 \x01(\r\x12\n\n\x02to\x18\x02 \x01(\r\"U\n\x07Snippet\x12\x10\n\x08\x66ragment\x18\x01 \x01(\x0c\x12*\n\nhighlights\x18\x02 \x03(\x0b\x32\x16.summa.proto.Highlight\x12\x0c\n\x04html\x18\x03 \x01(\t\"\xf0\x01\n\x0eScoredDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x10\n\x08position\x18\x03 \x01(\r\x12;\n\x08snippets\x18\x04 \x03(\x0b\x32).summa.proto.ScoredDocument.SnippetsEntry\x12\x13\n\x0bindex_alias\x18\x05 \x01(\t\x1a\x45\n\rSnippetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.summa.proto.Snippet:\x02\x38\x01\";\n\x06Scorer\x12\x13\n\teval_expr\x18\x01 \x01(\tH\x00\x12\x12\n\x08order_by\x18\x02 \x01(\tH\x00\x42\x08\n\x06scorer\"\xa8\x02\n\tCollector\x12\x31\n\x08top_docs\x18\x01 \x01(\x0b\x32\x1d.summa.proto.TopDocsCollectorH\x00\x12\x45\n\x12reservoir_sampling\x18\x02 \x01(\x0b\x32\'.summa.proto.ReservoirSamplingCollectorH\x00\x12,\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.summa.proto.CountCollectorH\x00\x12,\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32\x1b.summa.proto.FacetCollectorH\x00\x12\x38\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32!.summa.proto.AggregationCollectorH\x00\x42\x0b\n\tcollector\"\x89\x02\n\x0f\x43ollectorOutput\x12:\n\tdocuments\x18\x01 \x01(\x0b\x32%.summa.proto.DocumentsCollectorOutputH\x00\x12\x32\n\x05\x63ount\x18\x03 \x01(\x0b\x32!.summa.proto.CountCollectorOutputH\x00\x12\x32\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32!.summa.proto.FacetCollectorOutputH\x00\x12>\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32\'.summa.proto.AggregationCollectorOutputH\x00\x42\x12\n\x10\x63ollector_output\"\x10\n\x0e\x43ountCollector\"%\n\x14\x43ountCollectorOutput\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"/\n\x0e\x46\x61\x63\x65tCollector\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63\x65ts\x18\x02 \x03(\t\"\x94\x01\n\x14\x46\x61\x63\x65tCollectorOutput\x12H\n\x0c\x66\x61\x63\x65t_counts\x18\x01 \x03(\x0b\x32\x32.summa.proto.FacetCollectorOutput.FacetCountsEntry\x1a\x32\n\x10\x46\x61\x63\x65tCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\";\n\x1aReservoirSamplingCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"Z\n\x0eRandomDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x13\n\x0bindex_alias\x18\x03 \x01(\t\"R\n ReservoirSamplingCollectorOutput\x12.\n\tdocuments\x18\x01 \x03(\x0b\x32\x1b.summa.proto.RandomDocument\"\x8a\x02\n\x10TopDocsCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12(\n\x06scorer\x18\x03 \x01(\x0b\x32\x13.summa.proto.ScorerH\x00\x88\x01\x01\x12J\n\x0fsnippet_configs\x18\x04 \x03(\x0b\x32\x31.summa.proto.TopDocsCollector.SnippetConfigsEntry\x12\x0f\n\x07\x65xplain\x18\x05 \x01(\x08\x12\x0e\n\x06\x66ields\x18\x06 \x03(\t\x1a\x35\n\x13SnippetConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x42\t\n\x07_scorer\"c\n\x18\x44ocumentsCollectorOutput\x12\x35\n\x10scored_documents\x18\x01 \x03(\x0b\x32\x1b.summa.proto.ScoredDocument\x12\x10\n\x08has_next\x18\x02 \x01(\x08\",\n\x14\x41ggregationCollector\x12\x14\n\x0c\x61ggregations\x18\x01 \x01(\t\"9\n\x1a\x41ggregationCollectorOutput\x12\x1b\n\x13\x61ggregation_results\x18\x01 \x01(\t*+\n\x05Occur\x12\n\n\x06should\x10\x00\x12\x08\n\x04must\x10\x01\x12\x0c\n\x08must_not\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUERYPARSERCONFIG_FIELDALIASESENTRY._options = None
  _QUERYPARSERCONFIG_FIELDALIASESENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_FIELDBOOSTSENTRY._options = None
  _QUERYPARSERCONFIG_FIELDBOOSTSENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY._options = None
  _QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY._serialized_options = b'8\001'
  _QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY._options = None
  _QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY._serialized_options = b'8\001'
  _SCOREDDOCUMENT_SNIPPETSENTRY._options = None
  _SCOREDDOCUMENT_SNIPPETSENTRY._serialized_options = b'8\001'
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._options = None
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._serialized_options = b'8\001'
  _TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY._options = None
  _TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY._serialized_options = b'8\001'
  _globals['_OCCUR']._serialized_start=5460
  _globals['_OCCUR']._serialized_end=5503
  _globals['_TERMFIELDMAPPERCONFIG']._serialized_start=41
  _globals['_TERMFIELDMAPPERCONFIG']._serialized_end=80
  _globals['_MATCHQUERYBOOLEANSHOULDMODE']._serialized_start=82
  _globals['_MATCHQUERYBOOLEANSHOULDMODE']._serialized_end=111
  _globals['_MATCHQUERYDISJUCTIONMAXMODE']._serialized_start=113
  _globals['_MATCHQUERYDISJUCTIONMAXMODE']._serialized_end=163
  _globals['_EXACTMATCHESPROMOTER']._serialized_start=165
  _globals['_EXACTMATCHESPROMOTER']._serialized_end=247
  _globals['_NERMATCHESPROMOTER']._serialized_start=249
  _globals['_NERMATCHESPROMOTER']._serialized_end=315
  _globals['_MORPHOLOGYCONFIG']._serialized_start=317
  _globals['_MORPHOLOGYCONFIG']._serialized_end=405
  _globals['_QUERYPARSERCONFIG']._serialized_start=408
  _globals['_QUERYPARSERCONFIG']._serialized_end=1387
  _globals['_QUERYPARSERCONFIG_FIELDALIASESENTRY']._serialized_start=1061
  _globals['_QUERYPARSERCONFIG_FIELDALIASESENTRY']._serialized_end=1112
  _globals['_QUERYPARSERCONFIG_FIELDBOOSTSENTRY']._serialized_start=1114
  _globals['_QUERYPARSERCONFIG_FIELDBOOSTSENTRY']._serialized_end=1164
  _globals['_QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY']._serialized_start=1166
  _globals['_QUERYPARSERCONFIG_TERMFIELDMAPPERCONFIGSENTRY']._serialized_end=1263
  _globals['_QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY']._serialized_start=1265
  _globals['_QUERYPARSERCONFIG_MORPHOLOGYCONFIGSENTRY']._serialized_end=1352
  _globals['_SEARCHRESPONSE']._serialized_start=1389
  _globals['_SEARCHRESPONSE']._serialized_end=1484
  _globals['_QUERY']._serialized_start=1487
  _globals['_QUERY']._serialized_end=2044
  _globals['_ALLQUERY']._serialized_start=2046
  _globals['_ALLQUERY']._serialized_end=2056
  _globals['_EMPTYQUERY']._serialized_start=2058
  _globals['_EMPTYQUERY']._serialized_end=2070
  _globals['_BOOSTQUERY']._serialized_start=2072
  _globals['_BOOSTQUERY']._serialized_end=2134
  _globals['_DISJUNCTIONMAXQUERY']._serialized_start=2136
  _globals['_DISJUNCTIONMAXQUERY']._serialized_end=2217
  _globals['_MORELIKETHISQUERY']._serialized_start=2220
  _globals['_MORELIKETHISQUERY']._serialized_end=2621
  _globals['_PHRASEQUERY']._serialized_start=2623
  _globals['_PHRASEQUERY']._serialized_end=2680
  _globals['_RANGEQUERY']._serialized_start=2682
  _globals['_RANGEQUERY']._serialized_end=2744
  _globals['_MATCHQUERY']._serialized_start=2746
  _globals['_MATCHQUERY']._serialized_end=2863
  _globals['_BOOLEANSUBQUERY']._serialized_start=2865
  _globals['_BOOLEANSUBQUERY']._serialized_end=2952
  _globals['_BOOLEANQUERY']._serialized_start=2954
  _globals['_BOOLEANQUERY']._serialized_end=3018
  _globals['_REGEXQUERY']._serialized_start=3020
  _globals['_REGEXQUERY']._serialized_end=3062
  _globals['_TERMQUERY']._serialized_start=3064
  _globals['_TERMQUERY']._serialized_end=3105
  _globals['_EXISTSQUERY']._serialized_start=3107
  _globals['_EXISTSQUERY']._serialized_end=3135
  _globals['_CUSTOMORDER']._serialized_start=3138
  _globals['_CUSTOMORDER']._serialized_end=3301
  _globals['_KEY']._serialized_start=3303
  _globals['_KEY']._serialized_end=3345
  _globals['_RANGE']._serialized_start=3347
  _globals['_RANGE']._serialized_end=3432
  _globals['_SCORE']._serialized_start=3434
  _globals['_SCORE']._serialized_end=3492
  _globals['_HIGHLIGHT']._serialized_start=3494
  _globals['_HIGHLIGHT']._serialized_end=3531
  _globals['_SNIPPET']._serialized_start=3533
  _globals['_SNIPPET']._serialized_end=3618
  _globals['_SCOREDDOCUMENT']._serialized_start=3621
  _globals['_SCOREDDOCUMENT']._serialized_end=3861
  _globals['_SCOREDDOCUMENT_SNIPPETSENTRY']._serialized_start=3792
  _globals['_SCOREDDOCUMENT_SNIPPETSENTRY']._serialized_end=3861
  _globals['_SCORER']._serialized_start=3863
  _globals['_SCORER']._serialized_end=3922
  _globals['_COLLECTOR']._serialized_start=3925
  _globals['_COLLECTOR']._serialized_end=4221
  _globals['_COLLECTOROUTPUT']._serialized_start=4224
  _globals['_COLLECTOROUTPUT']._serialized_end=4489
  _globals['_COUNTCOLLECTOR']._serialized_start=4491
  _globals['_COUNTCOLLECTOR']._serialized_end=4507
  _globals['_COUNTCOLLECTOROUTPUT']._serialized_start=4509
  _globals['_COUNTCOLLECTOROUTPUT']._serialized_end=4546
  _globals['_FACETCOLLECTOR']._serialized_start=4548
  _globals['_FACETCOLLECTOR']._serialized_end=4595
  _globals['_FACETCOLLECTOROUTPUT']._serialized_start=4598
  _globals['_FACETCOLLECTOROUTPUT']._serialized_end=4746
  _globals['_FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY']._serialized_start=4696
  _globals['_FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY']._serialized_end=4746
  _globals['_RESERVOIRSAMPLINGCOLLECTOR']._serialized_start=4748
  _globals['_RESERVOIRSAMPLINGCOLLECTOR']._serialized_end=4807
  _globals['_RANDOMDOCUMENT']._serialized_start=4809
  _globals['_RANDOMDOCUMENT']._serialized_end=4899
  _globals['_RESERVOIRSAMPLINGCOLLECTOROUTPUT']._serialized_start=4901
  _globals['_RESERVOIRSAMPLINGCOLLECTOROUTPUT']._serialized_end=4983
  _globals['_TOPDOCSCOLLECTOR']._serialized_start=4986
  _globals['_TOPDOCSCOLLECTOR']._serialized_end=5252
  _globals['_TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY']._serialized_start=5188
  _globals['_TOPDOCSCOLLECTOR_SNIPPETCONFIGSENTRY']._serialized_end=5241
  _globals['_DOCUMENTSCOLLECTOROUTPUT']._serialized_start=5254
  _globals['_DOCUMENTSCOLLECTOROUTPUT']._serialized_end=5353
  _globals['_AGGREGATIONCOLLECTOR']._serialized_start=5355
  _globals['_AGGREGATIONCOLLECTOR']._serialized_end=5399
  _globals['_AGGREGATIONCOLLECTOROUTPUT']._serialized_start=5401
  _globals['_AGGREGATIONCOLLECTOROUTPUT']._serialized_end=5458
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import index_service_pb2 as index__service__pb2


class IndexApiStub(object):
    """Manages indices
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.attach_index = channel.unary_unary(
                '/summa.proto.IndexApi/attach_index',
                request_serializer=index__service__pb2.AttachIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.AttachIndexResponse.FromString,
                )
        self.commit_index = channel.unary_unary(
                '/summa.proto.IndexApi/commit_index',
                request_serializer=index__service__pb2.CommitIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.CommitIndexResponse.FromString,
                )
        self.copy_documents = channel.unary_unary(
                '/summa.proto.IndexApi/copy_documents',
                request_serializer=index__service__pb2.CopyDocumentsRequest.SerializeToString,
                response_deserializer=index__service__pb2.CopyDocumentsResponse.FromString,
                )
        self.create_index = channel.unary_unary(
                '/summa.proto.IndexApi/create_index',
                request_serializer=index__service__pb2.CreateIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.CreateIndexResponse.FromString,
                )
        self.copy_index = channel.unary_unary(
                '/summa.proto.IndexApi/copy_index',
                request_serializer=index__service__pb2.CopyIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.CopyIndexResponse.FromString,
                )
        self.delete_documents = channel.unary_unary(
                '/summa.proto.IndexApi/delete_documents',
                request_serializer=index__service__pb2.DeleteDocumentsRequest.SerializeToString,
                response_deserializer=index__service__pb2.DeleteDocumentsResponse.FromString,
                )
        self.delete_index = channel.unary_unary(
                '/summa.proto.IndexApi/delete_index',
                request_serializer=index__service__pb2.DeleteIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.DeleteIndexResponse.FromString,
                )
        self.documents = channel.unary_stream(
                '/summa.proto.IndexApi/documents',
                request_serializer=index__service__pb2.DocumentsRequest.SerializeToString,
                response_deserializer=index__service__pb2.DocumentsResponse.FromString,
                )
        self.get_indices_aliases = channel.unary_unary(
                '/summa.proto.IndexApi/get_indices_aliases',
                request_serializer=index__service__pb2.GetIndicesAliasesRequest.SerializeToString,
                response_deserializer=index__service__pb2.GetIndicesAliasesResponse.FromString,
                )
        self.get_index = channel.unary_unary(
                '/summa.proto.IndexApi/get_index',
                request_serializer=index__service__pb2.GetIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.GetIndexResponse.FromString,
                )
        self.get_indices = channel.unary_unary(
                '/summa.proto.IndexApi/get_indices',
                request_serializer=index__service__pb2.GetIndicesRequest.SerializeToString,
                response_deserializer=index__service__pb2.GetIndicesResponse.FromString,
                )
        self.index_document_stream = channel.stream_unary(
                '/summa.proto.IndexApi/index_document_stream',
                request_serializer=index__service__pb2.IndexDocumentStreamRequest.SerializeToString,
                response_deserializer=index__service__pb2.IndexDocumentStreamResponse.FromString,
                )
        self.index_document = channel.unary_unary(
                '/summa.proto.IndexApi/index_document',
                request_serializer=index__service__pb2.IndexDocumentRequest.SerializeToString,
                response_deserializer=index__service__pb2.IndexDocumentResponse.FromString,
                )
        self.merge_segments = channel.unary_unary(
                '/summa.proto.IndexApi/merge_segments',
                request_serializer=index__service__pb2.MergeSegmentsRequest.SerializeToString,
                response_deserializer=index__service__pb2.MergeSegmentsResponse.FromString,
                )
        self.set_index_alias = channel.unary_unary(
                '/summa.proto.IndexApi/set_index_alias',
                request_serializer=index__service__pb2.SetIndexAliasRequest.SerializeToString,
                response_deserializer=index__service__pb2.SetIndexAliasResponse.FromString,
                )
        self.vacuum_index = channel.unary_unary(
                '/summa.proto.IndexApi/vacuum_index',
                request_serializer=index__service__pb2.VacuumIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.VacuumIndexResponse.FromString,
                )
        self.warmup_index = channel.unary_unary(
                '/summa.proto.IndexApi/warmup_index',
                request_serializer=index__service__pb2.WarmupIndexRequest.SerializeToString,
                response_deserializer=index__service__pb2.WarmupIndexResponse.FromString,
                )


class IndexApiServicer(object):
    """Manages indices
    """

    def attach_index(self, request, context):
        """Attaches index to Summa server. Attaching allows to incorporate and start using of downloaded or network indices
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def commit_index(self, request, context):
        """Committing all collected writes to the index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def copy_documents(self, request, context):
        """Copy documents from one index to another
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_index(self, request, context):
        """Creates new index from scratch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def copy_index(self, request, context):
        """Creates new index from scratch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_documents(self, request, context):
        """Deletes single document from the index by its primary key (therefore, index must have primary key)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_index(self, request, context):
        """Deletes index and physically removes file in the case of `FileEngine`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def documents(self, request, context):
        """Stream of all documents from the index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_indices_aliases(self, request, context):
        """Gets all existing index aliases
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_index(self, request, context):
        """Gets index description
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_indices(self, request, context):
        """Gets all existing index descriptions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def index_document_stream(self, request_iterator, context):
        """Adds document to the index in a streaming way
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def index_document(self, request, context):
        """Adds document to the index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def merge_segments(self, request, context):
        """Merges multiple segments into a single one. Used for service purposes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_index_alias(self, request, context):
        """Sets or replaces existing index alias
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def vacuum_index(self, request, context):
        """Removes deletions from all segments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def warmup_index(self, request, context):
        """Loads all hot parts of the index into the memory
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IndexApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'attach_index': grpc.unary_unary_rpc_method_handler(
                    servicer.attach_index,
                    request_deserializer=index__service__pb2.AttachIndexRequest.FromString,
                    response_serializer=index__service__pb2.AttachIndexResponse.SerializeToString,
            ),
            'commit_index': grpc.unary_unary_rpc_method_handler(
                    servicer.commit_index,
                    request_deserializer=index__service__pb2.CommitIndexRequest.FromString,
                    response_serializer=index__service__pb2.CommitIndexResponse.SerializeToString,
            ),
            'copy_documents': grpc.unary_unary_rpc_method_handler(
                    servicer.copy_documents,
                    request_deserializer=index__service__pb2.CopyDocumentsRequest.FromString,
                    response_serializer=index__service__pb2.CopyDocumentsResponse.SerializeToString,
            ),
            'create_index': grpc.unary_unary_rpc_method_handler(
                    servicer.create_index,
                    request_deserializer=index__service__pb2.CreateIndexRequest.FromString,
                    response_serializer=index__service__pb2.CreateIndexResponse.SerializeToString,
            ),
            'copy_index': grpc.unary_unary_rpc_method_handler(
                    servicer.copy_index,
                    request_deserializer=index__service__pb2.CopyIndexRequest.FromString,
                    response_serializer=index__service__pb2.CopyIndexResponse.SerializeToString,
            ),
            'delete_documents': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_documents,
                    request_deserializer=index__service__pb2.DeleteDocumentsRequest.FromString,
                    response_serializer=index__service__pb2.DeleteDocumentsResponse.SerializeToString,
            ),
            'delete_index': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_index,
                    request_deserializer=index__service__pb2.DeleteIndexRequest.FromString,
                    response_serializer=index__service__pb2.DeleteIndexResponse.SerializeToString,
            ),
            'documents': grpc.unary_stream_rpc_method_handler(
                    servicer.documents,
                    request_deserializer=index__service__pb2.DocumentsRequest.FromString,
                    response_serializer=index__service__pb2.DocumentsResponse.SerializeToString,
            ),
            'get_indices_aliases': grpc.unary_unary_rpc_method_handler(
                    servicer.get_indices_aliases,
                    request_deserializer=index__service__pb2.GetIndicesAliasesRequest.FromString,
                    response_serializer=index__service__pb2.GetIndicesAliasesResponse.SerializeToString,
            ),
            'get_index': grpc.unary_unary_rpc_method_handler(
                    servicer.get_index,
                    request_deserializer=index__service__pb2.GetIndexRequest.FromString,
                    response_serializer=index__service__pb2.GetIndexResponse.SerializeToString,
            ),
            'get_indices': grpc.unary_unary_rpc_method_handler(
                    servicer.get_indices,
                    request_deserializer=index__service__pb2.GetIndicesRequest.FromString,
                    response_serializer=index__service__pb2.GetIndicesResponse.SerializeToString,
            ),
            'index_document_stream': grpc.stream_unary_rpc_method_handler(
                    servicer.index_document_stream,
                    request_deserializer=index__service__pb2.IndexDocumentStreamRequest.FromString,
                    response_serializer=index__service__pb2.IndexDocumentStreamResponse.SerializeToString,
            ),
            'index_document': grpc.unary_unary_rpc_method_handler(
                    servicer.index_document,
                    request_deserializer=index__service__pb2.IndexDocumentRequest.FromString,
                    response_serializer=index__service__pb2.IndexDocumentResponse.SerializeToString,
            ),
            'merge_segments': grpc.unary_unary_rpc_method_handler(
                    servicer.merge_segments,
                    request_deserializer=index__service__pb2.MergeSegmentsRequest.FromString,
                    response_serializer=index__service__pb2.MergeSegmentsResponse.SerializeToString,
            ),
            'set_index_alias': grpc.unary_unary_rpc_method_handler(
                    servicer.set_index_alias,
                    request_deserializer=index__service__pb2.SetIndexAliasRequest.FromString,
                    response_serializer=index__service__pb2.SetIndexAliasResponse.SerializeToString,
            ),
            'vacuum_index': grpc.unary_unary_rpc_method_handler(
                    servicer.vacuum_index,
                    request_deserializer=index__service__pb2.VacuumIndexRequest.FromString,
                    response_serializer=index__service__pb2.VacuumIndexResponse.SerializeToString,
            ),
            'warmup_index': grpc.unary_unary_rpc_method_handler(
                    servicer.warmup_index,
                    request_deserializer=index__service__pb2.WarmupIndexRequest.FromString,
                    response_serializer=index__service__pb2.WarmupIndexResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'summa.proto.IndexApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IndexApi(object):
    """Manages indices
    """

    @staticmethod
    def attach_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/attach_index',
            index__service__pb2.AttachIndexRequest.SerializeToString,
            index__service__pb2.AttachIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def commit_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/commit_index',
            index__service__pb2.CommitIndexRequest.SerializeToString,
            index__service__pb2.CommitIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def copy_documents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/copy_documents',
            index__service__pb2.CopyDocumentsRequest.SerializeToString,
            index__service__pb2.CopyDocumentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/create_index',
            index__service__pb2.CreateIndexRequest.SerializeToString,
            index__service__pb2.CreateIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def copy_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/copy_index',
            index__service__pb2.CopyIndexRequest.SerializeToString,
            index__service__pb2.CopyIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_documents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/delete_documents',
            index__service__pb2.DeleteDocumentsRequest.SerializeToString,
            index__service__pb2.DeleteDocumentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/delete_index',
            index__service__pb2.DeleteIndexRequest.SerializeToString,
            index__service__pb2.DeleteIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def documents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/summa.proto.IndexApi/documents',
            index__service__pb2.DocumentsRequest.SerializeToString,
            index__service__pb2.DocumentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_indices_aliases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/get_indices_aliases',
            index__service__pb2.GetIndicesAliasesRequest.SerializeToString,
            index__service__pb2.GetIndicesAliasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/get_index',
            index__service__pb2.GetIndexRequest.SerializeToString,
            index__service__pb2.GetIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_indices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/get_indices',
            index__service__pb2.GetIndicesRequest.SerializeToString,
            index__service__pb2.GetIndicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def index_document_stream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/summa.proto.IndexApi/index_document_stream',
            index__service__pb2.IndexDocumentStreamRequest.SerializeToString,
            index__service__pb2.IndexDocumentStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def index_document(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/index_document',
            index__service__pb2.IndexDocumentRequest.SerializeToString,
            index__service__pb2.IndexDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def merge_segments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/merge_segments',
            index__service__pb2.MergeSegmentsRequest.SerializeToString,
            index__service__pb2.MergeSegmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_index_alias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/set_index_alias',
            index__service__pb2.SetIndexAliasRequest.SerializeToString,
            index__service__pb2.SetIndexAliasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def vacuum_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/vacuum_index',
            index__service__pb2.VacuumIndexRequest.SerializeToString,
            index__service__pb2.VacuumIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def warmup_index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.IndexApi/warmup_index',
            index__service__pb2.WarmupIndexRequest.SerializeToString,
            index__service__pb2.WarmupIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: consumer_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63onsumer_service.proto\x12\x0bsumma.proto\"\x7f\n\x15\x43reateConsumerRequest\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x03(\t\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12\x12\n\nindex_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\x12\x0e\n\x06topics\x18\x05 \x03(\t\"A\n\x16\x43reateConsumerResponse\x12\'\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x15.summa.proto.Consumer\".\n\x15\x44\x65leteConsumerRequest\x12\x15\n\rconsumer_name\x18\x01 \x01(\t\"/\n\x16\x44\x65leteConsumerResponse\x12\x15\n\rconsumer_name\x18\x02 \x01(\t\"?\n\x12GetConsumerRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x15\n\rconsumer_name\x18\x02 \x01(\t\">\n\x13GetConsumerResponse\x12\'\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x15.summa.proto.Consumer\"\x15\n\x13GetConsumersRequest\"@\n\x14GetConsumersResponse\x12(\n\tconsumers\x18\x01 \x03(\x0b\x32\x15.summa.proto.Consumer\"5\n\x08\x43onsumer\x12\x15\n\rconsumer_name\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t2\xf6\x02\n\x0b\x43onsumerApi\x12\\\n\x0f\x63reate_consumer\x12\".summa.proto.CreateConsumerRequest\x1a#.summa.proto.CreateConsumerResponse\"\x00\x12S\n\x0cget_consumer\x12\x1f.summa.proto.GetConsumerRequest\x1a .summa.proto.GetConsumerResponse\"\x00\x12V\n\rget_consumers\x12 .summa.proto.GetConsumersRequest\x1a!.summa.proto.GetConsumersResponse\"\x00\x12\\\n\x0f\x64\x65lete_consumer\x12\".summa.proto.DeleteConsumerRequest\x1a#.summa.proto.DeleteConsumerResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'consumer_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CREATECONSUMERREQUEST']._serialized_start=39
  _globals['_CREATECONSUMERREQUEST']._serialized_end=166
  _globals['_CREATECONSUMERRESPONSE']._serialized_start=168
  _globals['_CREATECONSUMERRESPONSE']._serialized_end=233
  _globals['_DELETECONSUMERREQUEST']._serialized_start=235
  _globals['_DELETECONSUMERREQUEST']._serialized_end=281
  _globals['_DELETECONSUMERRESPONSE']._serialized_start=283
  _globals['_DELETECONSUMERRESPONSE']._serialized_end=330
  _globals['_GETCONSUMERREQUEST']._serialized_start=332
  _globals['_GETCONSUMERREQUEST']._serialized_end=395
  _globals['_GETCONSUMERRESPONSE']._serialized_start=397
  _globals['_GETCONSUMERRESPONSE']._serialized_end=459
  _globals['_GETCONSUMERSREQUEST']._serialized_start=461
  _globals['_GETCONSUMERSREQUEST']._serialized_end=482
  _globals['_GETCONSUMERSRESPONSE']._serialized_start=484
  _globals['_GETCONSUMERSRESPONSE']._serialized_end=548
  _globals['_CONSUMER']._serialized_start=550
  _globals['_CONSUMER']._serialized_end=603
  _globals['_CONSUMERAPI']._serialized_start=606
  _globals['_CONSUMERAPI']._serialized_end=980
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: unixfs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cunixfs.proto\x12\x06unixfs\"\x9b\x02\n\x04\x44\x61ta\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.unixfs.Data.DataType\x12\x11\n\x04\x64\x61ta\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x12\x15\n\x08\x66ilesize\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\nblocksizes\x18\x04 \x03(\x04\x12\x15\n\x08hashType\x18\x05 \x01(\x04H\x02\x88\x01\x01\x12\x13\n\x06\x66\x61nout\x18\x06 \x01(\x04H\x03\x88\x01\x01\"V\n\x08\x44\x61taType\x12\x07\n\x03Raw\x10\x00\x12\r\n\tDirectory\x10\x01\x12\x08\n\x04\x46ile\x10\x02\x12\x0c\n\x08Metadata\x10\x03\x12\x0b\n\x07Symlink\x10\x04\x12\r\n\tHAMTShard\x10\x05\x42\x07\n\x05_dataB\x0b\n\t_filesizeB\x0b\n\t_hashTypeB\t\n\x07_fanout\".\n\x08Metadata\x12\x15\n\x08MimeType\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_MimeTypeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'unixfs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DATA']._serialized_start=25
  _globals['_DATA']._serialized_end=308
  _globals['_DATA_DATATYPE']._serialized_start=176
  _globals['_DATA_DATATYPE']._serialized_end=262
  _globals['_METADATA']._serialized_start=310
  _globals['_METADATA']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dag_pb.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x61g_pb.proto\x12\x06\x64\x61g_pb\"`\n\x06PBLink\x12\x11\n\x04hash\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06t_size\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x07\n\x05_hashB\x07\n\x05_nameB\t\n\x07_t_size\"C\n\x06PBNode\x12\x1d\n\x05links\x18\x02 \x03(\x0b\x32\x0e.dag_pb.PBLink\x12\x11\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x42\x07\n\x05_datab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dag_pb_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PBLINK']._serialized_start=24
  _globals['_PBLINK']._serialized_end=120
  _globals['_PBNODE']._serialized_start=122
  _globals['_PBNODE']._serialized_end=189
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import query_pb2 as query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14search_service.proto\x12\x0bsumma.proto\x1a\x0bquery.proto\"\xc1\x01\n\rSearchRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\x12*\n\ncollectors\x18\x03 \x03(\x0b\x32\x16.summa.proto.Collector\x12*\n\x1dis_fieldnorms_scoring_enabled\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42 \n\x1e_is_fieldnorms_scoring_enabled2P\n\tSearchApi\x12\x43\n\x06search\x12\x1a.summa.proto.SearchRequest\x1a\x1b.summa.proto.SearchResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'search_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SEARCHREQUEST']._serialized_start=51
  _globals['_SEARCHREQUEST']._serialized_end=244
  _globals['_SEARCHAPI']._serialized_start=246
  _globals['_SEARCHAPI']._serialized_end=326
# @@protoc_insertion_point(module_scope)
